@@ -1,9 +1,11 @@
 context('peakPantheR_singleFileSearch()')
 
-skip_if(getRversion() >= "3.6")
 skip_if_not_installed('faahKO',  minimum_version = '1.18.0')
 library(faahKO)
 
+# remove Rplots.pdf created by ggplot2
+on.exit( tryCatch({ file.remove('./Rplots.pdf') }, error=function(e){ invisible() }, warning=function(w){ invisible() }) )
+
 
 ## Input and expected data
 # use ko15.CDf file from the pkg faahKO
@@ -11,21 +13,21 @@ singleSpectraDataPath <- system.file('cdf/KO/ko15.CDF', package = "faahKO")
 tmp_raw_data  				<- MSnbase::readMSData(singleSpectraDataPath, centroided=TRUE, mode='onDisk')
 
 # targeted features in faahKO
-input_ROI     	<- data.frame(matrix(vector(), 4, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=F)
+input_ROI     	<- data.frame(matrix(vector(), 4, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=FALSE)
 input_ROI[1,] 	<- c("ID-1", "testCpd 1", 3310., 3344.888, 3390., 522.194778, 522.2, 522.205222)
 input_ROI[2,] 	<- c("ID-2", "testCpd 2", 3280., 3385.577, 3440., 496.195038, 496.2, 496.204962)
 input_ROI[3,] 	<- c("ID-3", "testCpd 3", 3420., 3454.435, 3495., 464.195358, 464.2, 464.204642)
 input_ROI[4,] 	<- c("ID-4", "testCpd 4", 3670., 3701.697, 3745., 536.194638, 536.2, 536.205362)
-input_ROI[,3:8] <- sapply(input_ROI[,3:8], as.numeric)
+input_ROI[,3:8] <- vapply(input_ROI[,3:8], as.numeric, FUN.VALUE=numeric(4))
 
-# found peakTable
-found_peakTable     <- data.frame(matrix(vector(), 4, 17, dimnames=list(c(), c("found", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax", "peakArea", "maxIntMeasured", "maxIntPredicted", "cpdID", "cpdName", "is_filled", "ppm_error", "rt_dev_sec", "tailingFactor", "asymmetryFactor"))),stringsAsFactors=F)
-found_peakTable[1,] <- c(TRUE, 3309.7589296586070, 3346.8277590361445, 3385.4098874628098, 522.194778, 522.20001220703125, 522.205222, 26133726.6811244078, 889280, 901015.80529226747, 'ID-1', 'testCpd 1', FALSE, 0.023376160866574614, 1.93975903614455092, 1.0153573486330891, 1.0268238825675249)
-found_peakTable[2,] <- c(TRUE, 3345.3766648628907, 3386.5288072289159, 3428.2788374983961, 496.20001220703125, 496.20001220703125, 496.20001220703125, 35472141.3330242932, 1128960, 1113576.69008227298, 'ID-2', 'testCpd 2', FALSE, 0.024601030353423384, 0.95180722891564074, 1.0053782620427065, 1.0093180792278085)
-found_peakTable[3,] <- c(TRUE, 3451.2075903614455, 3451.5072891566265, 3501.6697504924518, 464.195358, 464.20001220703125, 464.204642, 7498427.1583901159, 380736, 389632.13549519412, 'ID-3', 'testCpd 3', FALSE, 0.026296922148575364, 2.92771084337346110, 207.6939219686769036, 380.5019028782010082)
-found_peakTable[4,] <- c(TRUE, 3670.9201232710743, 3704.1427831325304, 3740.0172511251831, 536.20001220703125, 536.20001220703125, 536.20001220703125, 8626279.9788195733, 330176, 326763.87246511364, 'ID-4', 'testCpd 4', FALSE, 0.022765817240815486, 2.44578313253032320, 1.0305289730128095, 1.0536948855480386)
-found_peakTable[,c(1,13)]       <- sapply(found_peakTable[,c(1,13)], as.logical)
-found_peakTable[,c(2:10,14:17)] <- sapply(found_peakTable[,c(2:10,14:17)], as.numeric)
+# Expected peakTables
+found_peakTable     <- data.frame(matrix(vector(), 4, 18, dimnames=list(c(), c("found", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax", "peakArea", "peakAreaRaw", "maxIntMeasured", "maxIntPredicted", "cpdID", "cpdName", "is_filled", "ppm_error", "rt_dev_sec", "tailingFactor", "asymmetryFactor"))),stringsAsFactors=FALSE)
+found_peakTable[1,] <- c(TRUE, 3309.7589296586070, 3346.8277590361445, 3385.4098874628098, 522.194778, 522.20001220703125, 522.205222, 26133726.6811244078, 26071378, 889280, 901015.80529226747, 'ID-1', 'testCpd 1', FALSE, 0.023376160866574614, 1.93975903614455092, 1.0153573486330891, 1.0268238825675249)
+found_peakTable[2,] <- c(TRUE, 3345.3766648628907, 3386.5288072289159, 3428.2788374983961, 496.20001220703125, 496.20001220703125, 496.20001220703125, 35472141.3330242932, 36498367, 1128960, 1113576.69008227298, 'ID-2', 'testCpd 2', FALSE, 0.024601030353423384, 0.95180722891564074, 1.0053782620427065, 1.0093180792278085)
+found_peakTable[3,] <- c(TRUE, 3451.2075903614455, 3451.5072891566265, 3501.6697504924518, 464.195358, 464.20001220703125, 464.204642, 7498427.1583901159, 7608218, 380736, 389632.13549519412, 'ID-3', 'testCpd 3', FALSE, 0.026296922148575364, -2.92771084337346110, 207.6939219686769036, 380.5019028782010082)
+found_peakTable[4,] <- c(TRUE, 3670.9201232710743, 3704.1427831325304, 3740.0172511251831, 536.20001220703125, 536.20001220703125, 536.20001220703125, 8626279.9788195733, 8692184, 330176, 326763.87246511364, 'ID-4', 'testCpd 4', FALSE, 0.022765817240815486, 2.44578313253032320, 1.0305289730128095, 1.0536948855480386)
+found_peakTable[,c(1,14)]       <- vapply(found_peakTable[,c(1,14)], as.logical, FUN.VALUE=logical(4))
+found_peakTable[,c(2:11,15:18)] <- vapply(found_peakTable[,c(2:11,15:18)], as.numeric, FUN.VALUE=numeric(4))
 
 # found curveFit
 cFit1           <- list(amplitude=162404.8057918259, center=3341.888, sigma=0.078786133031045896, gamma=0.0018336101984172684, fitStatus=2, curveModel="skewedGaussian")
@@ -39,14 +41,14 @@ class(cFit4)    <- 'peakPantheR_curveFit'
 found_curveFit  <- list(cFit1, cFit2, cFit3, cFit4)
 
 # found ROIsDataPoint
-found_ROIsDataPoints <- extractSignalRawData(tmp_raw_data, rt=input_ROI[,c('rtMin','rtMax')], mz=input_ROI[,c('mzMin','mzMax')], verbose=F)
+found_ROIsDataPoints <- extractSignalRawData(tmp_raw_data, rt=input_ROI[,c('rtMin','rtMax')], mz=input_ROI[,c('mzMin','mzMax')], verbose=FALSE)
 
 
 test_that('no peakStatistic, no plotEICsPath, no getAcquTime, no FIR, no verbose', {
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- found_peakTable[,1:13]
+  expected_peakTable      <- found_peakTable[,1:14]
   # Expected curveFit
   expected_curveFit       <- found_curveFit
   # Expected ROIsDataPoint
@@ -61,8 +63,8 @@ test_that('no peakStatistic, no plotEICsPath, no getAcquTime, no FIR, no verbose
 
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
 
@@ -90,8 +92,8 @@ test_that('peakStatistic, no plotEICsPath, no getAcquTime, no FIR, no verbose',
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -104,7 +106,7 @@ test_that('no peakStatistic, no plotEICsPath, with getAcquTime, no FIR, verbose'
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- found_peakTable[,1:13]
+  expected_peakTable      <- found_peakTable[,1:14]
   # Expected curveFit
   expected_curveFit       <- found_curveFit
   # Expected ROIsDataPoint
@@ -119,8 +121,8 @@ test_that('no peakStatistic, no plotEICsPath, with getAcquTime, no FIR, verbose'
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -133,7 +135,7 @@ test_that('no peakStatistic, with plotEICsPath, no getAcquTime, no FIR, verbose'
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- found_peakTable[,1:13]
+  expected_peakTable      <- found_peakTable[,1:14]
   # Expected curveFit
   expected_curveFit       <- found_curveFit
   # Expected ROIsDataPoint
@@ -151,8 +153,8 @@ test_that('no peakStatistic, with plotEICsPath, no getAcquTime, no FIR, verbose'
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -186,8 +188,8 @@ test_that('peakStatistic, plotEICsPath, getAcquTime, FIR, verbose', {
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -203,8 +205,8 @@ test_that('change peak fitting params with ..., no peakStatistic, no plotEICsPat
   # Expected TIC
   expected_TIC                      <- 2410533091
   # Expected peakTable
-  expected_peakTable                <- found_peakTable[,1:13]
-  expected_peakTable[3,2:10]        <- c(3418.0076795585401, 3455.6277710843374, 3495.4734240188186, 464.195358, 464.2000122, 464.204642, 11307215.264967661, 380736, 381327.26552768378)
+  expected_peakTable                <- found_peakTable[,1:14]
+  expected_peakTable[3,2:11]        <- c(3418.0076795585401, 3455.6277710843374, 3495.4734240188186, 464.195358, 464.2000122, 464.204642, 11307215.264967661, 11538988, 380736, 381327.26552768378)
   # Expected curveFit
   expected_curveFit                 <- found_curveFit
   expected_curveFit[[3]]$amplitude  <- 64246.052173667762
@@ -230,7 +232,7 @@ test_that('change peak fitting params with ..., no peakStatistic, no plotEICsPat
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-7)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-5)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
@@ -242,12 +244,12 @@ test_that('change peak fitting params with ..., no peakStatistic, no plotEICsPat
 
 test_that('no targetFeatures on import, no peakStatistic', {
   # Empty targetFeatures
-  empty_ROI   <- data.frame(matrix(vector(), 0, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=F)
+  empty_ROI   <- data.frame(matrix(vector(), 0, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=FALSE)
   
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- data.frame(matrix(vector(), 0, 13, dimnames=list(c(), c('cpdID', 'cpdName', 'found', 'rt', 'rtMin', 'rtMax', 'mz', 'mzMin', 'mzMax', 'peakArea', 'maxIntMeasured', 'maxIntPredicted', 'is_filled'))), stringsAsFactors=F)
+  expected_peakTable      <- data.frame(matrix(vector(), 0, 14, dimnames=list(c(), c('cpdID', 'cpdName', 'found', 'rt', 'rtMin', 'rtMax', 'mz', 'mzMin', 'mzMax', 'peakArea', 'peakAreaRaw', 'maxIntMeasured', 'maxIntPredicted', 'is_filled'))), stringsAsFactors=FALSE)
   # Expected curveFit
   expected_curveFit       <- list()
   # Expected ROIsDataPoint
@@ -262,8 +264,8 @@ test_that('no targetFeatures on import, no peakStatistic', {
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -274,12 +276,12 @@ test_that('no targetFeatures on import, no peakStatistic', {
 
 test_that('no targetFeatures on import, peakStatistic', {
   # Empty targetFeatures
-  empty_ROI   <- data.frame(matrix(vector(), 0, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=F)
+  empty_ROI   <- data.frame(matrix(vector(), 0, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))),stringsAsFactors=FALSE)
   
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- data.frame(matrix(vector(), 0, 17, dimnames=list(c(), c('cpdID', 'cpdName', 'found', 'rt', 'rtMin', 'rtMax', 'mz', 'mzMin', 'mzMax', 'peakArea', 'maxIntMeasured', 'maxIntPredicted', 'is_filled', 'ppm_error', 'rt_dev_sec', 'tailingFactor', 'asymmetryFactor'))), stringsAsFactors=F)
+  expected_peakTable      <- data.frame(matrix(vector(), 0, 18, dimnames=list(c(), c('cpdID', 'cpdName', 'found', 'rt', 'rtMin', 'rtMax', 'mz', 'mzMin', 'mzMax', 'peakArea', 'peakAreaRaw', 'maxIntMeasured', 'maxIntPredicted', 'is_filled', 'ppm_error', 'rt_dev_sec', 'tailingFactor', 'asymmetryFactor'))), stringsAsFactors=FALSE)
   # Expected curveFit
   expected_curveFit       <- list()
   # Expected ROIsDataPoint
@@ -294,8 +296,8 @@ test_that('no targetFeatures on import, peakStatistic', {
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -312,7 +314,7 @@ test_that('no features found, no FIR', {
   # Expected TIC
   expected_TIC                  <- 2410533091
   # Expected peakTable
-  expected_peakTable            <- data.frame(matrix(vector(), 1, 13, dimnames=list(c(), c('found', 'rtMin', 'rt', 'rtMax', 'mzMin', 'mz', 'mzMax', 'peakArea', 'maxIntMeasured', 'maxIntPredicted', 'cpdID', 'cpdName', 'is_filled'))), stringsAsFactors=F)
+  expected_peakTable            <- data.frame(matrix(vector(), 1, 14, dimnames=list(c(), c('found', 'rtMin', 'rt', 'rtMax', 'mzMin', 'mz', 'mzMax', 'peakArea', 'peakAreaRaw', 'maxIntMeasured', 'maxIntPredicted', 'cpdID', 'cpdName', 'is_filled'))), stringsAsFactors=FALSE)
   expected_peakTable$cpdID      <- "ID-1"
   expected_peakTable$cpdName    <- "testCpd 1"
   expected_peakTable$found      <- FALSE
@@ -320,19 +322,19 @@ test_that('no features found, no FIR', {
   # Expected curveFit
   expected_curveFit             <- list(NA)
   # Expected ROIsDataPoint
-  expected_ROIsDataPoint        <- list(data.frame(rt=numeric(), mz=numeric(), int=numeric(), stringsAsFactors=F))
+  expected_ROIsDataPoint        <- list(data.frame(rt=numeric(), mz=numeric(), int=numeric(), stringsAsFactors=FALSE))
   # Expected acquTime
   expected_acquTime             <- NA
   # Expected messages
-  expected_messages             <- c( "Polarity can not be extracted from netCDF files, please set manually the polarity with the 'polarity' method.\n", "Reading data from 1 windows\n", "Fit of ROI #1 is unsuccessful (try error)\n")
+  expected_messages             <- c( "Polarity can not be extracted from netCDF files, please set manually the polarity with the 'polarity' method.\n", "Reading data from 1 windows\n", "Fit of ROI #1 is unsuccessful (try err)\n")
 
   # results (output, warnings and messages)
   result_singleFileSearch       <- evaluate_promise(peakPantheR_singleFileSearch(singleSpectraDataPath, noMatch_ROI, peakStatistic=FALSE, plotEICsPath=NA, getAcquTime=FALSE, FIR=NULL, verbose=TRUE))
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -353,8 +355,8 @@ test_that('one feature not found (#3), use FIR', {
   # Expected TIC
   expected_TIC            <- 2410533091
   # Expected peakTable
-  expected_peakTable      <- found_peakTable[,1:13]
-  expected_peakTable[3,c('rtMin','rt', 'rtMax', 'mzMin', 'mz', 'mzMax', 'peakArea', 'maxIntMeasured', 'maxIntPredicted')] <- c(3451.20759036145, 3454.435, 3501.66975049245, 464.194858, 464.2, 464.205142, 7799325, 380736, as.numeric(NA))
+  expected_peakTable      <- found_peakTable[,1:14]
+  expected_peakTable[3,c('rtMin','rt', 'rtMax', 'mzMin', 'mz', 'mzMax', 'peakArea', 'peakAreaRaw', 'maxIntMeasured', 'maxIntPredicted')] <- c(3451.20759036145, 3454.435, 3501.66975049245, 464.194858, 464.2, 464.205142, 7744647, 7744647, 380736, as.numeric(NA))
   expected_peakTable$found[3]     <- TRUE
   expected_peakTable$is_filled[3] <- TRUE
   # Expected curveFit
@@ -362,19 +364,19 @@ test_that('one feature not found (#3), use FIR', {
   expected_curveFit[[3]]  <- NA
   # Expected ROIsDataPoint
   expected_ROIsDataPoint      <- found_ROIsDataPoints
-  expected_ROIsDataPoint[[3]] <- data.frame(rt=numeric(), mz=numeric(), int=numeric(), stringsAsFactors=F)
+  expected_ROIsDataPoint[[3]] <- data.frame(rt=numeric(), mz=numeric(), int=numeric(), stringsAsFactors=FALSE)
   # Expected acquTime
   expected_acquTime       <- NA
   # Expected messages
-  expected_messages       <- c("Polarity can not be extracted from netCDF files, please set manually the polarity with the 'polarity' method.\n", "Reading data from 4 windows\n", "Warning: rtMin/rtMax outside of ROI; datapoints cannot be used for mzMin/mzMax calculation, approximate mz and returning ROI$mzMin and ROI$mzMax for ROI #1\n", "Fit of ROI #3 is unsuccessful (try error)\n", "1 features to integrate with FIR\n", "Reading data from 1 windows\n")
+  expected_messages       <- c("Polarity can not be extracted from netCDF files, please set manually the polarity with the 'polarity' method.\n", "Reading data from 4 windows\n", "Warning: rtMin/rtMax outside of ROI; datapoints cannot be used for mzMin/mzMax calculation, approximate mz and returning ROI$mzMin and ROI$mzMax for ROI #1\n", "Fit of ROI #3 is unsuccessful (try err)\n", "1 features to integrate with FIR\n", "Reading data from 1 windows\n")
   
   # results (output, warnings and messages)
   result_singleFileSearch <- evaluate_promise(peakPantheR_singleFileSearch(singleSpectraDataPath, tmp_ROI, peakStatistic=FALSE, plotEICsPath=NA, getAcquTime=FALSE, FIR=input_FIR, verbose=TRUE))
   
   # Check results
   expect_equal(result_singleFileSearch$result$TIC, expected_TIC)
-  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable)
-  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit)
+  expect_equal(result_singleFileSearch$result$peakTable, expected_peakTable, tolerance=1e-6)
+  expect_equal(result_singleFileSearch$result$curveFit, expected_curveFit, tolerance=1e-6)
   expect_equal(result_singleFileSearch$result$ROIsDataPoint, expected_ROIsDataPoint)
   expect_equal(result_singleFileSearch$result$acquTime, expected_acquTime)
   
@@ -391,8 +393,8 @@ test_that('raise errors', {
   wrongOutputFormat <- './notAPNG.txt'
   # FIR to trigger errors
   notADataFrame     <- 'not at dataframe'
-  wrongNbrows       <- data.frame(matrix(vector(), 2, 4, dimnames=list(c(), c("mzMin", "mzMax", "rtMin", "rtMax"))), stringsAsFactors=F)
-  wrongCols         <- data.frame(matrix(vector(), 4, 4, dimnames=list(c(), c("wrongCol name", "mzMax", "rtMin", "rtMax"))), stringsAsFactors=F)
+  wrongNbrows       <- data.frame(matrix(vector(), 2, 4, dimnames=list(c(), c("mzMin", "mzMax", "rtMin", "rtMax"))), stringsAsFactors=FALSE)
+  wrongCols         <- data.frame(matrix(vector(), 4, 4, dimnames=list(c(), c("wrongCol name", "mzMax", "rtMin", "rtMax"))), stringsAsFactors=FALSE)
 
   # singleSpectraDataPath doesnt exist
   expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath=fakeInputPath, input_ROI), "Check input, file*")
@@ -401,10 +403,21 @@ test_that('raise errors', {
   # save file is not a .png
   expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, input_ROI, plotEICsPath=wrongOutputFormat), "Check input, plotEICsPath file name*")
 
+  # not implemented curveModel
+  expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, input_ROI, curveModel='FakeModel'), "Error: \"curveModel\" must be one of: skewedGaussian, emgGaussian")
   # FIR is not a data.frame
   expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, input_ROI, FIR=notADataFrame), "Check input, FIR must be a data.frame not character")
   # FIR has wrong number of rows
   expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, input_ROI, FIR=wrongNbrows), "Check input, FIR must have the same number of rows as targetFeatTable")
   # FIR columns are wrong
   expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, input_ROI, FIR=wrongCols), 'Check input, FIR must have "mzMin", "mzMax", "rtMin" and "rtMax" as columns')
+  
+  # rtMin > rtMax
+  wrong_ROI_rt     <- input_ROI
+  wrong_ROI_rt[2,] <- c("ID-2", "testCpd 2", 3440., 3385.577, 3280., 496.195038, 496.2, 496.204962)
+  expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, wrong_ROI_rt), 'Check input, "rtMin" must be <= to "rtMax"')
+  # mzMin > mzMax
+  wrong_ROI_mz     <- input_ROI
+  wrong_ROI_mz[3,] <- c("ID-3", "testCpd 3", 3420., 3454.435, 3495., 464.204642, 464.2, 464.195358)
+  expect_error(peakPantheR_singleFileSearch(singleSpectraDataPath, wrong_ROI_mz), 'Check input, "mzMin" must be <= to "mzMax"')
 })
